You are viewing a plain text version of this content. The canonical link for it is here.
Posted to kalumet-commits@incubator.apache.org by jb...@apache.org on 2012/08/30 17:31:30 UTC

svn commit: r1379028 [3/7] - in /incubator/kalumet/trunk: ./ documentation/src/site/apt/ documentation/src/site/apt/adminguide/ documentation/src/site/apt/userguide/ documentation/src/site/apt/userguide/environment/ kalumet-modules/agent/src/main/java/...

Modified: incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/JMSServerUpdater.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/JMSServerUpdater.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SoftwareUpdater.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SoftwareUpdater.java Thu Aug 30 17:31:27 2012
@@ -24,18 +24,8 @@ import org.apache.kalumet.FileManipulato
 import org.apache.kalumet.KalumetException;
 import org.apache.kalumet.agent.Configuration;
 import org.apache.kalumet.agent.utils.EventUtils;
-import org.apache.kalumet.model.Agent;
-import org.apache.kalumet.model.Command;
-import org.apache.kalumet.model.ConfigurationFile;
-import org.apache.kalumet.model.Database;
-import org.apache.kalumet.model.Environment;
-import org.apache.kalumet.model.J2EEApplicationServer;
-import org.apache.kalumet.model.JDBCConnectionPool;
-import org.apache.kalumet.model.Kalumet;
-import org.apache.kalumet.model.Location;
-import org.apache.kalumet.model.Mapping;
-import org.apache.kalumet.model.Software;
-import org.apache.kalumet.model.SqlScript;
+import org.apache.kalumet.model.*;
+import org.apache.kalumet.model.JEEApplicationServer;
 import org.apache.kalumet.model.update.UpdateLog;
 import org.apache.kalumet.model.update.UpdateMessage;
 import org.apache.kalumet.utils.CommandUtils;
@@ -1247,10 +1237,10 @@ public class SoftwareUpdater
                   VariableUtils.replace( database.getConnectionPool(), environment.getVariables() );
                 JDBCConnectionPool connectionPool = null;
                 for ( Iterator applicationServerIterator =
-                        environment.getJ2EEApplicationServers().getJ2EEApplicationServers().iterator();
+                        environment.getJEEApplicationServers().getJEEApplicationServers().iterator();
                       applicationServerIterator.hasNext(); )
                 {
-                  J2EEApplicationServer applicationServer = (J2EEApplicationServer) applicationServerIterator.next();
+                  JEEApplicationServer applicationServer = (JEEApplicationServer) applicationServerIterator.next();
                   connectionPool = applicationServer.getJDBCConnectionPool( connectionPoolName );
                   if ( connectionPool != null )
                   {
@@ -1259,10 +1249,10 @@ public class SoftwareUpdater
                 }
                 if ( connectionPool == null )
                 {
-                  LOGGER.error( "JDBC connection pool {} is not found in any J2EE application servers",
+                  LOGGER.error( "JDBC connection pool {} is not found in any JEE application servers",
                                 connectionPoolName );
                   throw new UpdateException(
-                    "JDBC connection pool " + connectionPoolName + " is not found in any J2EE application servers" );
+                    "JDBC connection pool " + connectionPoolName + " is not found in any JEE application servers" );
                 }
                 user = VariableUtils.replace( connectionPool.getUser(), environment.getVariables() );
                 password = VariableUtils.replace( connectionPool.getPassword(), environment.getVariables() );
@@ -1355,10 +1345,10 @@ public class SoftwareUpdater
                 VariableUtils.replace( database.getConnectionPool(), environment.getVariables() );
               JDBCConnectionPool connectionPool = null;
               for ( Iterator applicationServerIterator =
-                      environment.getJ2EEApplicationServers().getJ2EEApplicationServers().iterator();
+                      environment.getJEEApplicationServers().getJEEApplicationServers().iterator();
                     applicationServerIterator.hasNext(); )
               {
-                J2EEApplicationServer applicationServer = (J2EEApplicationServer) applicationServerIterator.next();
+                JEEApplicationServer applicationServer = (JEEApplicationServer) applicationServerIterator.next();
                 connectionPool = applicationServer.getJDBCConnectionPool( connectionPoolName );
                 if ( connectionPool != null )
                 {
@@ -1367,10 +1357,10 @@ public class SoftwareUpdater
               }
               if ( connectionPool == null )
               {
-                LOGGER.error( "JDBC connection pool {} is not found in any J2EE application servers",
+                LOGGER.error( "JDBC connection pool {} is not found in any JEE application servers",
                               connectionPoolName );
                 throw new UpdateException(
-                  "JDBC connection pool " + connectionPoolName + " is not found in any J2EE application servers" );
+                  "JDBC connection pool " + connectionPoolName + " is not found in any JEE application servers" );
               }
               user = VariableUtils.replace( connectionPool.getUser(), environment.getVariables() );
               password = VariableUtils.replace( connectionPool.getPassword(), environment.getVariables() );

Modified: incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SqlScriptUpdater.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SqlScriptUpdater.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/agent/src/main/resources/apache-kalumet.wsdd (original)
+++ incubator/kalumet/trunk/kalumet-modules/agent/src/main/resources/apache-kalumet.wsdd Thu Aug 30 17:31:27 2012
@@ -51,17 +51,17 @@
     <parameter name="className" value="org.apache.kalumet.agent.updater.EnvironmentUpdater"/>
   </service>
 
-  <service name="J2EEApplicationServerService" provider="java:RPC">
+  <service name="JEEApplicationServerService" provider="java:RPC">
     <parameter name="allowedMethods" value="start
             stop
             status
             update"/>
-    <parameter name="className" value="org.apache.kalumet.agent.updater.J2EEApplicationServerUpdater"/>
+    <parameter name="className" value="org.apache.kalumet.agent.updater.JEEApplicationServerUpdater"/>
   </service>
 
-  <service name="J2EEApplicationService" provider="java:RPC">
+  <service name="JEEApplicationService" provider="java:RPC">
     <parameter name="allowedMethods" value="update"/>
-    <parameter name="className" value="org.apache.kalumet.agent.updater.J2EEApplicationUpdater"/>
+    <parameter name="className" value="org.apache.kalumet.agent.updater.JEEApplicationUpdater"/>
   </service>
 
   <service name="ArchiveService" provider="java:RPC">

Modified: incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/FileManipulator.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/FileManipulator.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/Agent.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/Agent.java Thu Aug 30 17:31:27 2012
@@ -43,7 +43,7 @@ public class Agent
 
   private int maxmanagedenvironments;
 
-  private int maxj2eeapplicationserversstarted;
+  private int maxjeeapplicationserversstarted;
 
   public Agent()
   {
@@ -99,14 +99,14 @@ public class Agent
     this.maxmanagedenvironments = maxmanagedenvironments;
   }
 
-  public int getMaxj2eeapplicationserversstarted()
+  public int getMaxjeeapplicationserversstarted()
   {
-    return this.maxj2eeapplicationserversstarted;
+    return this.maxjeeapplicationserversstarted;
   }
 
-  public void setMaxj2eeapplicationserversstarted( int maxenvironmentsactive )
+  public void setMaxjeeapplicationserversstarted(int maxenvironmentsactive)
   {
-    this.maxj2eeapplicationserversstarted = maxenvironmentsactive;
+    this.maxjeeapplicationserversstarted = maxenvironmentsactive;
   }
 
   /**
@@ -121,7 +121,7 @@ public class Agent
     clone.setPort( this.getPort() );
     clone.setCron( this.getCron() );
     clone.setMaxmanagedenvironments( this.getMaxmanagedenvironments() );
-    clone.setMaxj2eeapplicationserversstarted( this.getMaxj2eeapplicationserversstarted() );
+    clone.setMaxjeeapplicationserversstarted(this.getMaxjeeapplicationserversstarted());
     return clone;
   }
 
@@ -139,8 +139,8 @@ public class Agent
     element.setAttribute( "port", new Integer( this.getPort() ).toString() );
     element.setAttribute( "cron", this.getCron() );
     element.setAttribute( "maxmanagedenvironments", new Integer( this.getMaxmanagedenvironments() ).toString() );
-    element.setAttribute( "maxj2eeapplicationserversstarted",
-                          new Integer( this.getMaxj2eeapplicationserversstarted() ).toString() );
+    element.setAttribute( "maxjeeapplicationserversstarted",
+                          new Integer( this.getMaxjeeapplicationserversstarted() ).toString() );
     return element;
   }
 

Modified: incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/Environment.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/Environment.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/Environment.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/Environment.java Thu Aug 30 17:31:27 2012
@@ -61,7 +61,7 @@ public class Environment
 
   private LinkedList accesses;
 
-  private J2EEApplicationServers j2EEApplicationServers;
+  private JEEApplicationServers jeeApplicationServers;
 
   private LinkedList softwares;
 
@@ -78,7 +78,7 @@ public class Environment
     this.variables = new LinkedList();
     this.freeFields = new LinkedList();
     this.accesses = new LinkedList();
-    this.j2EEApplicationServers = new J2EEApplicationServers();
+    this.jeeApplicationServers = new JEEApplicationServers();
     this.softwares = new LinkedList();
     this.logFiles = new LinkedList();
     this.notifiers = new Notifiers();
@@ -351,25 +351,25 @@ public class Environment
   }
 
   /**
-   * Set the <code>J2EEApplicationServers</code> container in the
+   * Set the <code>JEEApplicationServers</code> container in the
    * <code>Environment</code>.
    *
-   * @param j2EEApplicationServers the <code>J2EEApplicationServers</code> to set.
+   * @param jeeApplicationServers the <code>JEEApplicationServers</code> to set.
    */
-  public void setJ2EEApplicationServers( J2EEApplicationServers j2EEApplicationServers )
+  public void setJEEApplicationServers(JEEApplicationServers jeeApplicationServers)
   {
-    this.j2EEApplicationServers = j2EEApplicationServers;
+    this.jeeApplicationServers = jeeApplicationServers;
   }
 
   /**
-   * Get the <code>J2EEApplicationServers</code> container in the
+   * Get the <code>JEEApplicationServers</code> container in the
    * <code>Environment</code>.
    *
-   * @return the <code>J2EEApplicationServers</code> container.
+   * @return the <code>JEEApplicationServers</code> container.
    */
-  public J2EEApplicationServers getJ2EEApplicationServers()
+  public JEEApplicationServers getJEEApplicationServers()
   {
-    return this.j2EEApplicationServers;
+    return this.jeeApplicationServers;
   }
 
   /**
@@ -615,7 +615,7 @@ public class Environment
       Access access = (Access) accessIterator.next();
       clone.accesses.add( (Access) access.clone() );
     }
-    clone.setJ2EEApplicationServers( (J2EEApplicationServers) this.getJ2EEApplicationServers().clone() );
+    clone.setJEEApplicationServers((JEEApplicationServers) this.getJEEApplicationServers().clone());
     for ( Iterator softwareIterator = this.softwares.iterator(); softwareIterator.hasNext(); )
     {
       Software software = (Software) softwareIterator.next();
@@ -692,8 +692,8 @@ public class Environment
     CDATASectionImpl weblinksContent = new CDATASectionImpl( document, this.getWeblinks() );
     weblinks.appendChild( weblinksContent );
     element.appendChild( weblinks );
-    // add J2EE servers
-    element.appendChild( this.getJ2EEApplicationServers().toDOMElement( document ) );
+    // add JEE servers
+    element.appendChild( this.getJEEApplicationServers().toDOMElement( document ) );
     // softwares element
     ElementImpl softwares = new ElementImpl( document, "softwares" );
     // add software to softwares

Copied: incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplication.java (from r1377266, incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/J2EEApplication.java)
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplication.java?p2=incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplication.java&p1=incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/J2EEApplication.java&r1=1377266&r2=1379028&rev=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/J2EEApplication.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplication.java Thu Aug 30 17:31:27 2012
@@ -28,9 +28,9 @@ import java.util.LinkedList;
 import java.util.List;
 
 /**
- * Represents the <code>j2eeapplication</code> tag in the Kalumet DOM.
+ * Represents the <code>jeeapplication</code> tag in the Kalumet DOM.
  */
-public class J2EEApplication
+public class JEEApplication
   implements Serializable, Cloneable, Comparable
 {
 
@@ -55,9 +55,9 @@ public class J2EEApplication
   private LinkedList databases;
 
   /**
-   * Default constructor to create a <code>J2EEApplication</code>
+   * Default constructor to create a <code>JEEApplication</code>
    */
-  public J2EEApplication()
+  public JEEApplication()
   {
     this.archives = new LinkedList();
     this.contentManagers = new LinkedList();
@@ -116,7 +116,7 @@ public class J2EEApplication
   }
 
   /**
-   * Add a new <code>Archive</code> in the <code>J2EEApplication</code> archives container.
+   * Add a new <code>Archive</code> in the <code>JEEApplication</code> archives container.
    *
    * @param archive the <code>Archive</code> to add.
    * @throws ModelObjectAlreadyExistsException
@@ -133,7 +133,7 @@ public class J2EEApplication
   }
 
   /**
-   * Get the <code>Archive</code> list in the <code>J2EEApplication</code> archives container.
+   * Get the <code>Archive</code> list in the <code>JEEApplication</code> archives container.
    *
    * @return the <code>Archive</code> list
    */
@@ -143,7 +143,7 @@ public class J2EEApplication
   }
 
   /**
-   * Overwrite the <code>Archive</code> list in the <code>J2EEApplication</code> archives container.
+   * Overwrite the <code>Archive</code> list in the <code>JEEApplication</code> archives container.
    *
    * @param archives the new <code>Archive</code> list.
    */
@@ -153,7 +153,7 @@ public class J2EEApplication
   }
 
   /**
-   * Get the <code>Archive</code> identified by a given name in the <code>J2EEApplication</code> archives container.
+   * Get the <code>Archive</code> identified by a given name in the <code>JEEApplication</code> archives container.
    *
    * @param name the <code>Archive</code> name.
    * @return the <code>Archive</code> found or null if not found.
@@ -172,7 +172,7 @@ public class J2EEApplication
   }
 
   /**
-   * Add a new <code>ContentManager</code> in the <code>J2EEApplication</code> content managers container.
+   * Add a new <code>ContentManager</code> in the <code>JEEApplication</code> content managers container.
    *
    * @param contentManager the <code>ContentManager</code> to add.
    * @throws ModelObjectAlreadyExistsException
@@ -189,7 +189,7 @@ public class J2EEApplication
   }
 
   /**
-   * Get the <code>ContentManager</code> list in the <code>J2EEApplication</code> content managers container.
+   * Get the <code>ContentManager</code> list in the <code>JEEApplication</code> content managers container.
    *
    * @return the <code>ContentManager</code> list.
    */
@@ -199,7 +199,7 @@ public class J2EEApplication
   }
 
   /**
-   * Overwrite the <code>ContentManager</code> list in the <code>J2EEApplication</code> content managers container.
+   * Overwrite the <code>ContentManager</code> list in the <code>JEEApplication</code> content managers container.
    *
    * @param contentManagers the new <code>ContentManagers</code> list.
    */
@@ -209,7 +209,7 @@ public class J2EEApplication
   }
 
   /**
-   * Return the <code>ContentManager</code> identified by a given name in the <code>J2EEApplication</code> content managers container.
+   * Return the <code>ContentManager</code> identified by a given name in the <code>JEEApplication</code> content managers container.
    *
    * @return the <code>ContentManager</code> found or null if not found.
    */
@@ -227,7 +227,7 @@ public class J2EEApplication
   }
 
   /**
-   * Add a new <code>ConfigurationFile</code> in the <code>J2EEApplication</code>
+   * Add a new <code>ConfigurationFile</code> in the <code>JEEApplication</code>
    * configuration files container.
    *
    * @param configurationFile the <code>ConfigurationFile</code> to add.
@@ -246,7 +246,7 @@ public class J2EEApplication
 
   /**
    * Get the <code>ConfigurationFile</code> list in the
-   * <code>J2EEApplication</code> configuration files container.
+   * <code>JEEApplication</code> configuration files container.
    *
    * @return the <code>ConfigurationFile</code> list.
    */
@@ -257,7 +257,7 @@ public class J2EEApplication
 
   /**
    * Overwrite the <code>ConfigurationFile</code> list in the
-   * <code>J2EEApplication</code> configuration files container.
+   * <code>JEEApplication</code> configuration files container.
    *
    * @param configurationFiles the new <code>ConfigurationFile</code> list.
    */
@@ -268,7 +268,7 @@ public class J2EEApplication
 
   /**
    * Get the <code>ConfigurationFile</code> identified by a given name in the
-   * <code>J2EEApplication</code> configuration files container.
+   * <code>JEEApplication</code> configuration files container.
    *
    * @param name the <code>ConfigurationFile</code> name.
    * @return the <code>ConfigurationFile</code> found or null if not found.
@@ -288,7 +288,7 @@ public class J2EEApplication
   }
 
   /**
-   * Add a new <code>Database</code> in the <code>J2EEApplication</code>
+   * Add a new <code>Database</code> in the <code>JEEApplication</code>
    * databases container.
    *
    * @param database the <code>Database</code> to add.
@@ -300,13 +300,13 @@ public class J2EEApplication
   {
     if ( this.getDatabase( database.getName() ) != null )
     {
-      throw new ModelObjectAlreadyExistsException( "Database name already exists in the J2EE application." );
+      throw new ModelObjectAlreadyExistsException( "Database name already exists in the JEE application." );
     }
     this.databases.add( database );
   }
 
   /**
-   * Get the <code>Database</code> list in the <code>J2EEApplication</code>
+   * Get the <code>Database</code> list in the <code>JEEApplication</code>
    * databases container.
    *
    * @return the <code>Database</code> list.
@@ -317,7 +317,7 @@ public class J2EEApplication
   }
 
   /**
-   * Overwrite the <code>Database</code> list in the <code>J2EEApplication</code>
+   * Overwrite the <code>Database</code> list in the <code>JEEApplication</code>
    * databases container.
    *
    * @param databases the new <code>Database</code> list.
@@ -329,7 +329,7 @@ public class J2EEApplication
 
   /**
    * Get the <code>Database</code> identified by a given name in the
-   * <code>J2EEApplication</code> databases container.
+   * <code>JEEApplication</code> databases container.
    *
    * @param name the <code>Database</code> name.
    * @return the <code>Database</code> found or null if not found.
@@ -353,7 +353,7 @@ public class J2EEApplication
   public Object clone()
     throws CloneNotSupportedException
   {
-    J2EEApplication clone = new J2EEApplication();
+    JEEApplication clone = new JEEApplication();
     clone.setName( this.getName() );
     clone.setUri( this.getUri() );
     clone.setActive( this.isActive() );
@@ -384,14 +384,14 @@ public class J2EEApplication
   }
 
   /**
-   * Transforms the <code>J2EEApplication</code> POJO to a DOM element.
+   * Transforms the <code>JEEApplication</code> POJO to a DOM element.
    *
    * @param document the core DOM document.
    * @return the DOM element.
    */
   protected Element toDOMElement( CoreDocumentImpl document )
   {
-    ElementImpl element = new ElementImpl( document, "j2eeapplication" );
+    ElementImpl element = new ElementImpl( document, "jeeapplication" );
     element.setAttribute( "name", this.getName() );
     element.setAttribute( "uri", this.getUri() );
     element.setAttribute( "active", new Boolean( this.isActive() ).toString() );
@@ -438,7 +438,7 @@ public class J2EEApplication
    */
   public int compareTo( Object anotherApplication )
   {
-    return this.getName().compareTo( ( (J2EEApplication) anotherApplication ).getName() );
+    return this.getName().compareTo( ( (JEEApplication) anotherApplication ).getName() );
   }
 
 }
\ No newline at end of file

Copied: incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplicationServer.java (from r1377266, incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/J2EEApplicationServer.java)
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplicationServer.java?p2=incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplicationServer.java&p1=incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/J2EEApplicationServer.java&r1=1377266&r2=1379028&rev=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/J2EEApplicationServer.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplicationServer.java Thu Aug 30 17:31:27 2012
@@ -29,9 +29,9 @@ import java.util.LinkedList;
 import java.util.List;
 
 /**
- * Represents the <code>j2eeapplicationserver</code> tag in the Kalumet DOM.
+ * Represents the <code>jeeapplicationserver</code> tag in the Kalumet DOM.
  */
-public class J2EEApplicationServer
+public class JEEApplicationServer
   implements Serializable, Cloneable, Comparable
 {
 
@@ -77,16 +77,16 @@ public class J2EEApplicationServer
 
   private LinkedList sharedLibraries;
 
-  private LinkedList j2eeApplications;
+  private LinkedList jeeApplications;
 
   private LinkedList caches;
 
   private LinkedList logAccesses;
 
   /**
-   * Default constructor to create a new <code>J2EEApplicationServer</code>.
+   * Default constructor to create a new <code>JEEApplicationServer</code>.
    */
-  public J2EEApplicationServer()
+  public JEEApplicationServer()
   {
     this.jdbcConnectionPools = new LinkedList();
     this.jdbcDataSources = new LinkedList();
@@ -94,7 +94,7 @@ public class J2EEApplicationServer
     this.jmsServers = new LinkedList();
     this.jndiBindings = new LinkedList();
     this.sharedLibraries = new LinkedList();
-    this.j2eeApplications = new LinkedList();
+    this.jeeApplications = new LinkedList();
     this.caches = new LinkedList();
     this.logAccesses = new LinkedList();
   }
@@ -241,7 +241,7 @@ public class J2EEApplicationServer
 
   /**
    * Add a new <code>JDBCConnectionPool</code> in the
-   * <code>J2EEApplicationServer</code> connection pools container.
+   * <code>JEEApplicationServer</code> connection pools container.
    *
    * @param JDBCConnectionPool the <code>JDBCConnectionPool</code> to add.
    * @throws ModelObjectAlreadyExistsException
@@ -252,14 +252,14 @@ public class J2EEApplicationServer
   {
     if ( this.getJDBCConnectionPool( JDBCConnectionPool.getName() ) != null )
     {
-      throw new ModelObjectAlreadyExistsException( "JDBC connection pool name already exists in the JZEE server." );
+      throw new ModelObjectAlreadyExistsException( "JDBC connection pool name already exists in the JEE server." );
     }
     this.jdbcConnectionPools.add( JDBCConnectionPool );
   }
 
   /**
    * Get the <code>JDBCConnectionPool</code> list in the
-   * <code>J2EEApplicationServer</code> connection pools container.
+   * <code>JEEApplicationServer</code> connection pools container.
    *
    * @return the <code>JDBCConnectionPool</code> list.
    */
@@ -270,7 +270,7 @@ public class J2EEApplicationServer
 
   /**
    * Overwrite the <code>JDBCConnectionPool</code> list in the
-   * <code>J2EEApplicationServer</code> connection pools container.
+   * <code>JEEApplicationServer</code> connection pools container.
    *
    * @param jdbcConnectionPools the new <code>JDBCConnectionPool</code> list.
    */
@@ -281,7 +281,7 @@ public class J2EEApplicationServer
 
   /**
    * Get the <code>JDBCConnectionPool</code> identified by a given name in the
-   * <code>J2EEApplicationServer</code> connection pools container.
+   * <code>JEEApplicationServer</code> connection pools container.
    *
    * @param name the <code>JDBCConnectionPool</code> name.
    * @return the <code>JDBCConnectionPool</code> found or null if not found.
@@ -301,7 +301,7 @@ public class J2EEApplicationServer
   }
 
   /**
-   * Add a new <code>JDBCDataSource</code> in the <code>J2EEApplicationServer</code>
+   * Add a new <code>JDBCDataSource</code> in the <code>JEEApplicationServer</code>
    * data sources container.
    *
    * @param JDBCDataSource the <code>JDBCDataSource</code> to add.
@@ -313,14 +313,14 @@ public class J2EEApplicationServer
   {
     if ( this.getJDBCDataSource( JDBCDataSource.getName() ) != null )
     {
-      throw new ModelObjectAlreadyExistsException( "JDBC data source name already exists in the JZEE server." );
+      throw new ModelObjectAlreadyExistsException( "JDBC data source name already exists in the JEE server." );
     }
     this.jdbcDataSources.add( JDBCDataSource );
   }
 
   /**
    * Get the <code>JDBCDataSource</code> list in the
-   * <code>J2EEApplicationServer</code> data sources container.
+   * <code>JEEApplicationServer</code> data sources container.
    *
    * @return the <code>JDBCDataSource</code> list.
    */
@@ -331,7 +331,7 @@ public class J2EEApplicationServer
 
   /**
    * Overwrite the <code>JDBCDataSource</code> list in the
-   * <code>J2EEApplicationServer</code> data sources container.
+   * <code>JEEApplicationServer</code> data sources container.
    *
    * @param dataSources the new <code>JDBCDataSource</code> list.
    */
@@ -342,7 +342,7 @@ public class J2EEApplicationServer
 
   /**
    * Get the <code>JDBCDataSource</code> identified by a given name in the
-   * <code>J2EEApplicationServer</code> data sources container.
+   * <code>JEEApplicationServer</code> data sources container.
    *
    * @param name the <code>JDBCDataSource</code> name.
    * @return the <code>JDBCDataSource</code> found or null if not found.
@@ -362,7 +362,7 @@ public class J2EEApplicationServer
 
   /**
    * Add a new <code>JMSConnectionFactory</code> in the
-   * <code>J2EEApplicationServer</code> JMS connection factories container.
+   * <code>JEEApplicationServer</code> JMS connection factories container.
    *
    * @param jmsConnectionFactory the <code>JMSConnectionFactory</code> to add.
    * @throws ModelObjectAlreadyExistsException
@@ -373,14 +373,14 @@ public class J2EEApplicationServer
   {
     if ( this.getJMSConnectionFactory( jmsConnectionFactory.getName() ) != null )
     {
-      throw new ModelObjectAlreadyExistsException( "JMS connection factory name already exists in the JZEE server." );
+      throw new ModelObjectAlreadyExistsException( "JMS connection factory name already exists in the JEE server." );
     }
     this.jmsConnectionFactories.add( jmsConnectionFactory );
   }
 
   /**
    * Get the <code>JMSConnectionFactory</code> list in the
-   * <code>J2EEApplicationServer</code> JMS connection factories container.
+   * <code>JEEApplicationServer</code> JMS connection factories container.
    *
    * @return the <code>JMSConnectionFactory</code> list.
    */
@@ -391,7 +391,7 @@ public class J2EEApplicationServer
 
   /**
    * Overwrites the <code>JMSConnectionFactory</code> list in the
-   * <code>J2EEApplicationServer</code> JMS connection factories container.
+   * <code>JEEApplicationServer</code> JMS connection factories container.
    *
    * @param jmsConnectionFactories the new <code>JMSConnectionFactory</code> list.
    */
@@ -402,7 +402,7 @@ public class J2EEApplicationServer
 
   /**
    * Gets the <code>JMSConnectionFactory</code> identified by a given name in
-   * the <code>J2EEApplicationServer</code> JMS connection factories container.
+   * the <code>JEEApplicationServer</code> JMS connection factories container.
    *
    * @param name the <code>JMSConnectionFactory</code> name.
    * @return the <code>JMSConnectionFactory</code> found or null if not found.
@@ -422,7 +422,7 @@ public class J2EEApplicationServer
   }
 
   /**
-   * Adds a new <code>JMSServer</code> in the <code>J2EEApplicationServer</code>
+   * Adds a new <code>JMSServer</code> in the <code>JEEApplicationServer</code>
    * JMS servers container.
    *
    * @param jmsServer the <code>JMSServer</code> to add.
@@ -434,13 +434,13 @@ public class J2EEApplicationServer
   {
     if ( this.getJMSServer( jmsServer.getName() ) != null )
     {
-      throw new ModelObjectAlreadyExistsException( "JMS server name already exists in the JZEE application server." );
+      throw new ModelObjectAlreadyExistsException( "JMS server name already exists in the JEE application server." );
     }
     this.jmsServers.add( jmsServer );
   }
 
   /**
-   * Gets the <code>JMSServer</code> list in the <code>J2EEApplicationServer</code>
+   * Gets the <code>JMSServer</code> list in the <code>JEEApplicationServer</code>
    * JMS servers container.
    *
    * @return the <code>JMSServer</code> list.
@@ -452,7 +452,7 @@ public class J2EEApplicationServer
 
   /**
    * Overwrites the <code>JMSServer</code> list in the
-   * <code>J2EEApplicationServer</code> JMS servers container.
+   * <code>JEEApplicationServer</code> JMS servers container.
    *
    * @param jmsServers the new <code>JMSServer</code> list.
    */
@@ -463,7 +463,7 @@ public class J2EEApplicationServer
 
   /**
    * Gets the <code>JMSServer</code> identified by a given name in the
-   * <code>J2EEApplicationServer</code> JMS servers container.
+   * <code>JEEApplicationServer</code> JMS servers container.
    *
    * @param name the <code>JMSServer</code> name.
    * @return the <code>JMSServer</code> found or null if not found.
@@ -483,7 +483,7 @@ public class J2EEApplicationServer
 
   /**
    * Adds a new <code>JNDIBinding</code> in the
-   * <code>J2EEApplicationServer</code> name space bindings container.
+   * <code>JEEApplicationServer</code> name space bindings container.
    *
    * @param JNDIBinding the <code>JNDIBinding</code> to add.
    * @throws ModelObjectAlreadyExistsException
@@ -494,14 +494,14 @@ public class J2EEApplicationServer
   {
     if ( this.getJNDIBinding( JNDIBinding.getName() ) != null )
     {
-      throw new ModelObjectAlreadyExistsException( "Name space binding name already exists in the JZEE server." );
+      throw new ModelObjectAlreadyExistsException( "Name space binding name already exists in the JEE server." );
     }
     this.jndiBindings.add( JNDIBinding );
   }
 
   /**
    * Gets the <code>JNDIBinding</code> list in the
-   * <code>J2EEApplicationServer</code> name space bindings container.
+   * <code>JEEApplicationServer</code> name space bindings container.
    *
    * @return the <code>JNDIBinding</code> list.
    */
@@ -512,7 +512,7 @@ public class J2EEApplicationServer
 
   /**
    * Overwrites the <code>JNDIBinding</code> list in the
-   * <code>J2EEApplicationServer</code> name space bindings container.
+   * <code>JEEApplicationServer</code> name space bindings container.
    *
    * @param jndiBindings the new <code>JNDIBinding</code> list.
    */
@@ -523,7 +523,7 @@ public class J2EEApplicationServer
 
   /**
    * Gets the <code>JNDIBinding</code> identified by a given name in the
-   * <code>J2EEApplicationServer</code> name space bindings container.
+   * <code>JEEApplicationServer</code> name space bindings container.
    *
    * @param name the <code>JNDIBinding</code> name.
    * @return the <code>JNDIBinding</code> found or null if not found.
@@ -543,7 +543,7 @@ public class J2EEApplicationServer
 
   /**
    * Adds a new <code>SharedLibrary</code> in the
-   * <code>J2EEApplicationServer</code> shared libraries container.
+   * <code>JEEApplicationServer</code> shared libraries container.
    *
    * @param sharedLibrary the <code>SharedLibrary</code> to add.
    * @throws ModelObjectAlreadyExistsException
@@ -554,14 +554,14 @@ public class J2EEApplicationServer
   {
     if ( this.getSharedLibrary( sharedLibrary.getName() ) != null )
     {
-      throw new ModelObjectAlreadyExistsException( "Shared library name already exists in the JZEE server." );
+      throw new ModelObjectAlreadyExistsException( "Shared library name already exists in the JEE server." );
     }
     this.sharedLibraries.add( sharedLibrary );
   }
 
   /**
    * Gets the <code>SharedLibrary</code> list in the
-   * <code>J2EEApplicationServer</code> shared libraries container.
+   * <code>JEEApplicationServer</code> shared libraries container.
    *
    * @return the <code>SharedLibrary</code> list.
    */
@@ -572,7 +572,7 @@ public class J2EEApplicationServer
 
   /**
    * Overwrites the <code>SharedLibrary</code> list in the
-   * <code>J2EEApplicationServer</code> shared libraries container.
+   * <code>JEEApplicationServer</code> shared libraries container.
    *
    * @param sharedLibraries the new <code>SharedLibrary</code> list.
    */
@@ -583,7 +583,7 @@ public class J2EEApplicationServer
 
   /**
    * Gets the <code>SharedLibrary</code> identified by a given name in the
-   * <code>J2EEApplicationServer</code> shared libraries container.
+   * <code>JEEApplicationServer</code> shared libraries container.
    *
    * @param name the <code>SharedLibrary</code> name.
    * @return the <code>SharedLibrary</code> found or null if not found.
@@ -602,68 +602,68 @@ public class J2EEApplicationServer
   }
 
   /**
-   * Adds a new <code>J2EEApplication</code> in the <code>J2EEApplicationServer</code>
-   * j2eeApplications container.
+   * Adds a new <code>JEEApplication</code> in the <code>JEEApplicationServer</code>
+   * jeeApplications container.
    *
-   * @param j2eeApplication the <code>J2EEApplication</code> to add.
+   * @param jeeApplication the <code>JEEApplication</code> to add.
    * @throws ModelObjectAlreadyExistsException
-   *          if the <code>J2EEApplication</code> name already exists in the j2EEApplication server.
+   *          if the <code>JEEApplication</code> name already exists in the jeeApplication server.
    */
-  public void addJ2EEApplication( J2EEApplication j2eeApplication )
+  public void addJEEApplication( JEEApplication jeeApplication )
     throws ModelObjectAlreadyExistsException
   {
-    if ( this.getJ2EEApplication( j2eeApplication.getName() ) != null )
+    if ( this.getJEEApplication(jeeApplication.getName()) != null )
     {
       throw new ModelObjectAlreadyExistsException(
-        "J2EE application name already exists in the J2EE application server." );
+        "JEE application name already exists in the JEE application server." );
     }
-    this.j2eeApplications.add( j2eeApplication );
+    this.jeeApplications.add(jeeApplication);
   }
 
   /**
-   * Gets the <code>J2EEApplication</code> list in the
-   * <code>J2EEApplicationServer</code> j2eeApplications container.
+   * Gets the <code>JEEApplication</code> list in the
+   * <code>JEEApplicationServer</code> jeeApplications container.
    *
-   * @return the <code>J2EEApplication</code> list.
+   * @return the <code>JEEApplication</code> list.
    */
-  public List getJ2EEApplications()
+  public List getJEEApplications()
   {
-    return this.j2eeApplications;
+    return this.jeeApplications;
   }
 
   /**
-   * Overwrites the <code>J2EEApplication</code> list in the
-   * <code>J2EEApplicationServer</code> j2eeApplications container.
+   * Overwrites the <code>JEEApplication</code> list in the
+   * <code>JEEApplicationServer</code> jeeApplications container.
    *
-   * @param j2eeApplications the new <code>J2EEApplication</code> list.
+   * @param jeeApplications the new <code>JEEApplication</code> list.
    */
-  public void setJ2EEApplications( LinkedList j2eeApplications )
+  public void setJEEApplications( LinkedList jeeApplications )
   {
-    this.j2eeApplications = j2eeApplications;
+    this.jeeApplications = jeeApplications;
   }
 
   /**
-   * Gets the <code>J2EEApplication</code> identified by a given name in the
-   * <code>J2EEApplicationServer</code> j2eeApplications container.
+   * Gets the <code>JEEApplication</code> identified by a given name in the
+   * <code>JEEApplicationServer</code> jeeApplications container.
    *
-   * @param name the <code>J2EEApplication</code> name.
-   * @return the <code>J2EEApplication</code> found or null if not found.
+   * @param name the <code>JEEApplication</code> name.
+   * @return the <code>JEEApplication</code> found or null if not found.
    */
-  public J2EEApplication getJ2EEApplication( String name )
+  public JEEApplication getJEEApplication( String name )
   {
-    for ( Iterator applicationIterator = this.getJ2EEApplications().iterator(); applicationIterator.hasNext(); )
+    for ( Iterator applicationIterator = this.getJEEApplications().iterator(); applicationIterator.hasNext(); )
     {
-      J2EEApplication j2EEApplication = (J2EEApplication) applicationIterator.next();
-      if ( j2EEApplication.getName().equals( name ) )
+      JEEApplication jeeApplication = (JEEApplication) applicationIterator.next();
+      if ( jeeApplication.getName().equals( name ) )
       {
-        return j2EEApplication;
+        return jeeApplication;
       }
     }
     return null;
   }
 
   /**
-   * Adds a new <code>Cache</code> in the <code>J2EEApplicationServer</code> caches
+   * Adds a new <code>Cache</code> in the <code>JEEApplicationServer</code> caches
    * container.
    *
    * @param cache the <code>Cache</code> to add.
@@ -675,13 +675,13 @@ public class J2EEApplicationServer
   {
     if ( this.getCache( cache.getPath() ) != null )
     {
-      throw new ModelObjectAlreadyExistsException( "Cache path already exists in the J2EE application server." );
+      throw new ModelObjectAlreadyExistsException( "Cache path already exists in the JEE application server." );
     }
     this.caches.add( cache );
   }
 
   /**
-   * Gets the <code>Cache</code> list in the <code>J2EEApplicationServer</code>
+   * Gets the <code>Cache</code> list in the <code>JEEApplicationServer</code>
    * caches container.
    *
    * @return the <code>Cache</code> list.
@@ -693,7 +693,7 @@ public class J2EEApplicationServer
 
   /**
    * Overwrites the <code>Cache</code> list in the
-   * <code>J2EEApplicationServer</code> caches container.
+   * <code>JEEApplicationServer</code> caches container.
    *
    * @param caches the new <code>Cache</code> list.
    */
@@ -704,7 +704,7 @@ public class J2EEApplicationServer
 
   /**
    * Gets the <code>Cache</code> identified by a given path in the
-   * <code>J2EEApplicationServer</code> caches container.
+   * <code>JEEApplicationServer</code> caches container.
    *
    * @param path the <code>Cache</code> path.
    * @return the <code>Cache</code> found or null if not found.
@@ -728,7 +728,7 @@ public class J2EEApplicationServer
   public Object clone()
     throws CloneNotSupportedException
   {
-    J2EEApplicationServer clone = new J2EEApplicationServer();
+    JEEApplicationServer clone = new JEEApplicationServer();
     clone.setName( this.getName() );
     clone.setActive( this.isActive() );
     clone.setBlocker( this.isBlocker() );
@@ -775,10 +775,10 @@ public class J2EEApplicationServer
       SharedLibrary sharedLibrary = (SharedLibrary) sharedLibraryIterator.next();
       clone.sharedLibraries.add( (SharedLibrary) sharedLibrary.clone() );
     }
-    for ( Iterator applicationIterator = this.j2eeApplications.iterator(); applicationIterator.hasNext(); )
+    for ( Iterator applicationIterator = this.jeeApplications.iterator(); applicationIterator.hasNext(); )
     {
-      J2EEApplication j2EEApplication = (J2EEApplication) applicationIterator.next();
-      clone.j2eeApplications.add( (J2EEApplication) j2EEApplication.clone() );
+      JEEApplication jeeApplication = (JEEApplication) applicationIterator.next();
+      clone.jeeApplications.add( (JEEApplication) jeeApplication.clone() );
     }
     for ( Iterator cacheIterator = this.caches.iterator(); cacheIterator.hasNext(); )
     {
@@ -789,14 +789,14 @@ public class J2EEApplicationServer
   }
 
   /**
-   * Transforms the <code>J2EEApplicationServer</code> POJO to a DOM element.
+   * Transforms the <code>JEEApplicationServer</code> POJO to a DOM element.
    *
    * @param document the core XML document.
    * @return the DOM element.
    */
   protected Element toDOMElement( CoreDocumentImpl document )
   {
-    ElementImpl element = new ElementImpl( document, "j2eeapplicationserver" );
+    ElementImpl element = new ElementImpl( document, "jeeapplicationserver" );
     element.setAttribute( "name", this.getName() );
     element.setAttribute( "active", new Boolean( this.isActive() ).toString() );
     element.setAttribute( "blocker", new Boolean( this.isBlocker() ).toString() );
@@ -869,12 +869,12 @@ public class J2EEApplicationServer
       sharedlibraries.appendChild( sharedLibrary.toDOMElement( document ) );
     }
     element.appendChild( sharedlibraries );
-    // j2eeApplications
-    ElementImpl applications = new ElementImpl( document, "j2eeApplications" );
-    for ( Iterator applicationIterator = this.getJ2EEApplications().iterator(); applicationIterator.hasNext(); )
+    // jeeApplications
+    ElementImpl applications = new ElementImpl( document, "jeeApplications" );
+    for ( Iterator applicationIterator = this.getJEEApplications().iterator(); applicationIterator.hasNext(); )
     {
-      J2EEApplication j2EEApplication = (J2EEApplication) applicationIterator.next();
-      applications.appendChild( j2EEApplication.toDOMElement( document ) );
+      JEEApplication jeeApplication = (JEEApplication) applicationIterator.next();
+      applications.appendChild(jeeApplication.toDOMElement(document));
     }
     element.appendChild( applications );
     // caches
@@ -893,7 +893,7 @@ public class J2EEApplicationServer
    */
   public int compareTo( Object anotherApplicationServer )
   {
-    return this.getName().compareTo( ( (J2EEApplicationServer) anotherApplicationServer ).getName() );
+    return this.getName().compareTo( ( (JEEApplicationServer) anotherApplicationServer ).getName() );
   }
 
 }
\ No newline at end of file

Added: incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplicationServers.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplicationServers.java?rev=1379028&view=auto
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplicationServers.java (added)
+++ incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/JEEApplicationServers.java Thu Aug 30 17:31:27 2012
@@ -0,0 +1,154 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.kalumet.model;
+
+import org.apache.xerces.dom.CoreDocumentImpl;
+import org.apache.xerces.dom.ElementImpl;
+import org.w3c.dom.Element;
+
+import java.io.Serializable;
+import java.util.Iterator;
+import java.util.LinkedList;
+import java.util.List;
+
+/**
+ * Represents the <code>jeeapplicationservers</code> tag in the Kalumet DOM.
+ */
+public class JEEApplicationServers
+  implements Serializable, Cloneable
+{
+
+  private static final long serialVersionUID = -4940898204749451109L;
+
+  private boolean cluster;
+
+  private LinkedList jeeApplicationServers;
+
+  public JEEApplicationServers()
+  {
+    this.jeeApplicationServers = new LinkedList();
+  }
+
+  public boolean isCluster()
+  {
+    return this.cluster;
+  }
+
+  public void setCluster( boolean cluster )
+  {
+    this.cluster = cluster;
+  }
+
+  /**
+   * Adds a new <code>JEEApplicationServer</code> in the
+   * <code>JEEApplicationServers</code> container.
+   *
+   * @param jeeApplicationServer the <code>JEEApplicationServer</code> to add.
+   */
+  public void addJEEApplicationServer( JEEApplicationServer jeeApplicationServer )
+    throws ModelObjectAlreadyExistsException
+  {
+    if ( this.getJEEApplicationServer( jeeApplicationServer.getName() ) != null )
+    {
+      throw new ModelObjectAlreadyExistsException( "JEE application server name already exists in the environment." );
+    }
+    this.jeeApplicationServers.add(jeeApplicationServer);
+  }
+
+  /**
+   * Gets the <code>JEEApplicationServer</code> list in the
+   * <code>JEEApplicationServers</code> container.
+   *
+   * @return the <code>JEEApplicationServer</code> list.
+   */
+  public List getJEEApplicationServers()
+  {
+    return this.jeeApplicationServers;
+  }
+
+  /**
+   * Overwrites the <code>JEEApplicationServer</code> list in the
+   * <code>JEEApplicationServers</code> container.
+   *
+   * @param jeeApplicationServers the new <code>JEEApplicationServer</code> list.
+   */
+  public void setJEEApplicationServers( LinkedList jeeApplicationServers )
+  {
+    this.jeeApplicationServers = jeeApplicationServers;
+  }
+
+  /**
+   * Gets the <code>JEEApplicationServer</code> identified by a given name in the
+   * <code>JEEApplicationServers</code> container.
+   *
+   * @param name the <code>JEEApplicationServer</code> name.
+   * @return the <code>JEEApplicationServer</code> found or null if no found.
+   */
+  public JEEApplicationServer getJEEApplicationServer( String name )
+  {
+    for ( Iterator applicationServerIterator = this.getJEEApplicationServers().iterator();
+          applicationServerIterator.hasNext(); )
+    {
+      JEEApplicationServer jeeApplicationServer = (JEEApplicationServer) applicationServerIterator.next();
+      if ( jeeApplicationServer.getName().equals( name ) )
+      {
+        return jeeApplicationServer;
+      }
+    }
+    return null;
+  }
+
+  /**
+   * @see java.lang.Object#clone()
+   */
+  public Object clone()
+    throws CloneNotSupportedException
+  {
+    JEEApplicationServers clone = new JEEApplicationServers();
+    clone.setCluster( this.isCluster() );
+    for ( Iterator applicationServerIterator = this.jeeApplicationServers.iterator();
+          applicationServerIterator.hasNext(); )
+    {
+      JEEApplicationServer jeeApplicationServer = (JEEApplicationServer) applicationServerIterator.next();
+      clone.jeeApplicationServers.add( (JEEApplicationServer) jeeApplicationServer.clone() );
+    }
+    return clone;
+  }
+
+  /**
+   * Transforms the <code>JEEApplicationServers</code> POJO to a DOM element.
+   *
+   * @param document the DOM document.
+   * @return the DOM element.
+   */
+  protected Element toDOMElement( CoreDocumentImpl document )
+  {
+    ElementImpl element = new ElementImpl( document, "jeeapplicationservers" );
+    element.setAttribute( "cluster", new Boolean( this.isCluster() ).toString() );
+    // add JEE application server child nodes
+    for ( Iterator applicationServerIterator = this.getJEEApplicationServers().iterator();
+          applicationServerIterator.hasNext(); )
+    {
+      JEEApplicationServer jeeApplicationServer = (JEEApplicationServer) applicationServerIterator.next();
+      element.appendChild(jeeApplicationServer.toDOMElement(document));
+    }
+    return element;
+  }
+
+}
\ No newline at end of file
--- incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/JMSServerUpdater.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/JMSServerUpdater.java Thu Aug 30 17:31:27 2012
@@ -22,14 +22,10 @@ import org.apache.kalumet.KalumetExcepti
 import org.apache.kalumet.agent.Configuration;
 import org.apache.kalumet.agent.utils.EventUtils;
 import org.apache.kalumet.controller.core.ControllerException;
-import org.apache.kalumet.controller.core.J2EEApplicationServerController;
-import org.apache.kalumet.controller.core.J2EEApplicationServerControllerFactory;
-import org.apache.kalumet.model.Environment;
-import org.apache.kalumet.model.J2EEApplicationServer;
-import org.apache.kalumet.model.JMSQueue;
-import org.apache.kalumet.model.JMSServer;
-import org.apache.kalumet.model.JMSTopic;
-import org.apache.kalumet.model.Kalumet;
+import org.apache.kalumet.controller.core.JEEApplicationServerController;
+import org.apache.kalumet.controller.core.JEEApplicationServerControllerFactory;
+import org.apache.kalumet.model.*;
+import org.apache.kalumet.model.JEEApplicationServer;
 import org.apache.kalumet.model.update.UpdateLog;
 import org.apache.kalumet.model.update.UpdateMessage;
 import org.apache.kalumet.utils.NotifierUtils;
@@ -53,12 +49,12 @@ public class JMSServerUpdater
    * Update a JMS server.
    *
    * @param environment the target <code>Environment</code>.
    * @param server      the target <code>J2EEApplicationServer</code>.
    * @param jmsServer   the target <code>JMSServer</code>.
    * @param updateLog   the <code>UpdateLog</code> to use.
    * @thorws UpdateException in case of update failure.
    */
-  public static void update( Environment environment, J2EEApplicationServer server, JMSServer jmsServer,
+  public static void update( Environment environment, JEEApplicationServer server, JMSServer jmsServer,
                              UpdateLog updateLog )
     throws UpdateException
   {
@@ -89,17 +85,17 @@ public class JMSServerUpdater
       JMSTopic jmsTopic = (JMSTopic) topicIterator.next();
       topics.add( VariableUtils.replace( jmsTopic.getName(), environment.getVariables() ) );
     }
-    J2EEApplicationServerController controller = null;
+    JEEApplicationServerController controller = null;
     try
     {
       // connect JMX controller to JEE application server
-      LOGGER.debug( "Connecting to J2EE application server {} controller", server.getName() );
-      controller = J2EEApplicationServerControllerFactory.getController( environment, server );
+      LOGGER.debug( "Connecting to JEE application server {} controller", server.getName() );
+      controller = JEEApplicationServerControllerFactory.getController(environment, server);
     }
     catch ( KalumetException e )
     {
-      LOGGER.error( "Can't connect to J2EE application server {} controller", server.getName(), e );
-      throw new UpdateException( "Can't connect to J2EE application server " + server.getName() + " controller", e );
+      LOGGER.error( "Can't connect to JEE application server {} controller", server.getName(), e );
+      throw new UpdateException( "Can't connect to JEE application server " + server.getName() + " controller", e );
     }
     try
     {
@@ -138,7 +134,7 @@ public class JMSServerUpdater
    * Wrapper method to update a JMS server via WS.
    *
    * @param environmentName       the target environment name.
    * @param applicationServerName the target J2EE application server name.
    * @param jmsServerName         the target JMS server name.
    * @throws KalumetException if case of update failure.
    */
@@ -159,22 +155,22 @@ public class JMSServerUpdater
       LOGGER.error( "Environment {} is not found in the configuration", environmentName );
       throw new KalumetException( "Environment " + environmentName + " is not found in the configuration" );
     }
-    J2EEApplicationServer applicationServer =
-      environment.getJ2EEApplicationServers().getJ2EEApplicationServer( applicationServerName );
+    JEEApplicationServer applicationServer =
+      environment.getJEEApplicationServers().getJEEApplicationServer(applicationServerName);
     if ( applicationServer == null )
     {
-      LOGGER.error( "J2EE application server {} is not found in environment {}", applicationServerName,
+      LOGGER.error( "JEE application server {} is not found in environment {}", applicationServerName,
                     environment.getName() );
       throw new KalumetException(
-        "J2EE application server " + applicationServerName + " is not found in environment " + environment.getName() );
+        "JEE application server " + applicationServerName + " is not found in environment " + environment.getName() );
     }
     JMSServer jmsServer = applicationServer.getJMSServer( jmsServerName );
     if ( jmsServer == null )
     {
-      LOGGER.error( "JMS server {} is not found in J2EE application server {}", jmsServerName,
+      LOGGER.error( "JMS server {} is not found in JEE application server {}", jmsServerName,
                     applicationServer.getName() );
       throw new KalumetException(
-        "JMS server " + jmsServerName + " is not found in J2EE application server " + applicationServer.getName() );
+        "JMS server " + jmsServerName + " is not found in JEE application server " + applicationServer.getName() );
     }
 
     // post an event and create update log.
@@ -227,7 +223,7 @@ public class JMSServerUpdater
    * Check a JMS server via WS.
    *
    * @param environmentName       the target environment name.
    * @param applicationServerName the target J2EE application server name.
    * @param jmsServerName         the target JMS server name.
    * @return true if the JMS server is up to date, false else.
    * @throws KalumetException in case of check failure.
@@ -249,22 +245,22 @@ public class JMSServerUpdater
       LOGGER.error( "Environment {} is not found in the configuration", environmentName );
       throw new KalumetException( "Environment " + environmentName + " is not found in the configuration" );
     }
-    J2EEApplicationServer applicationServer =
-      environment.getJ2EEApplicationServers().getJ2EEApplicationServer( applicationServerName );
+    JEEApplicationServer applicationServer =
+      environment.getJEEApplicationServers().getJEEApplicationServer(applicationServerName);
     if ( applicationServer == null )
     {
-      LOGGER.error( "J2EE application server {} is not found in environment {}", applicationServerName,
+      LOGGER.error( "JEE application server {} is not found in environment {}", applicationServerName,
                     environment.getName() );
       throw new KalumetException(
-        "J2EE application server " + applicationServerName + " is not found in environment " + environment.getName() );
+        "JEE application server " + applicationServerName + " is not found in environment " + environment.getName() );
     }
     JMSServer jmsServer = applicationServer.getJMSServer( jmsServerName );
     if ( jmsServer == null )
     {
-      LOGGER.error( "JMS server {} is not found in J2EE application server {}", jmsServerName,
+      LOGGER.error( "JMS server {} is not found in JEE application server {}", jmsServerName,
                     applicationServer.getName() );
       throw new KalumetException(
-        "JMS server " + jmsServerName + " is not found in J2EE application server " + applicationServer.getName() );
+        "JMS server " + jmsServerName + " is not found in JEE application server " + applicationServer.getName() );
     }
 
     // post an event.
@@ -272,10 +268,10 @@ public class JMSServerUpdater
 
     try
     {
-      // get J2EE application server controller.
-      LOGGER.debug( "Getting J2EE application server controller" );
-      J2EEApplicationServerController controller =
-        J2EEApplicationServerControllerFactory.getController( environment, applicationServer );
+      // get JEE application server controller.
+      LOGGER.debug( "Getting JEE application server controller" );
+      JEEApplicationServerController controller =
+        JEEApplicationServerControllerFactory.getController(environment, applicationServer);
       // construct the queue list.
       LOGGER.debug( "Constructing the queue list" );
       LinkedList queues = new LinkedList();
@@ -53,12 +49,12 @@ public class JMSServerUpdater
    *
    * @param environment the target <code>Environment</code>.
-   * @param server      the target <code>J2EEApplicationServer</code>.
+   * @param server      the target <code>JEEApplicationServer</code>.
    * @param jmsServer   the target <code>JMSServer</code>.
    * @param updateLog   the <code>UpdateLog</code> to use.
@@ -138,7 +134,7 @@ public class JMSServerUpdater
    *
    * @param environmentName       the target environment name.
-   * @param applicationServerName the target J2EE application server name.
+   * @param applicationServerName the target JEE application server name.
    * @param jmsServerName         the target JMS server name.
    * @throws KalumetException if case of update failure.
@@ -227,7 +223,7 @@ public class JMSServerUpdater
    *
    * @param environmentName       the target environment name.
-   * @param applicationServerName the target J2EE application server name.
+   * @param applicationServerName the target JEE application server name.
    * @param jmsServerName         the target JMS server name.
    * @return true if the JMS server is up to date, false else.

Modified: incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/JNDIBindingUpdater.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/JNDIBindingUpdater.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/JNDIBindingUpdater.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/JNDIBindingUpdater.java Thu Aug 30 17:31:27 2012
@@ -22,10 +22,10 @@ import org.apache.kalumet.KalumetExcepti
 import org.apache.kalumet.agent.Configuration;
 import org.apache.kalumet.agent.utils.EventUtils;
 import org.apache.kalumet.controller.core.ControllerException;
-import org.apache.kalumet.controller.core.J2EEApplicationServerController;
-import org.apache.kalumet.controller.core.J2EEApplicationServerControllerFactory;
+import org.apache.kalumet.controller.core.JEEApplicationServerController;
+import org.apache.kalumet.controller.core.JEEApplicationServerControllerFactory;
 import org.apache.kalumet.model.Environment;
-import org.apache.kalumet.model.J2EEApplicationServer;
+import org.apache.kalumet.model.JEEApplicationServer;
 import org.apache.kalumet.model.JNDIBinding;
 import org.apache.kalumet.model.Kalumet;
 import org.apache.kalumet.model.update.UpdateLog;
@@ -48,12 +48,12 @@ public class JNDIBindingUpdater
    * Update a JNDI binding..
    *
    * @param environment the target <code>Environment</code>.
    * @param server      the target <code>J2EEApplicationServer</code>.
    * @param jndiBinding the target <code>JNDIBinding</code>.
    * @param updateLog   the <code>UpdateLog</code> to use.
    * @throws UpdateException in case of update failure.
    */
-  public static void update( Environment environment, J2EEApplicationServer server, JNDIBinding jndiBinding,
+  public static void update( Environment environment, JEEApplicationServer server, JNDIBinding jndiBinding,
                              UpdateLog updateLog )
     throws UpdateException
   {
@@ -70,17 +70,17 @@ public class JNDIBindingUpdater
                        "JNDI binding " + jndiBinding.getName() + " is inactive, so not updated" );
       return;
     }
-    J2EEApplicationServerController controller = null;
+    JEEApplicationServerController controller = null;
     try
     {
-      // connect controller to J2EE application server
-      LOGGER.debug( "Connecting to J2EE application server {} controller", server.getName() );
-      controller = J2EEApplicationServerControllerFactory.getController( environment, server );
+      // connect controller to JEE application server
+      LOGGER.debug( "Connecting to JEE application server {} controller", server.getName() );
+      controller = JEEApplicationServerControllerFactory.getController(environment, server);
     }
     catch ( KalumetException e )
     {
-      LOGGER.error( "Can't connect to J2EE application server {} controller", server.getName(), e );
-      throw new UpdateException( "Can't connect to J2EE application server " + server.getName() + " controller", e );
+      LOGGER.error( "Can't connect to JEE application server {} controller", server.getName(), e );
+      throw new UpdateException( "Can't connect to JEE application server " + server.getName() + " controller", e );
     }
     // replaces variables in name space binding data
     LOGGER.debug( "Replacing variables in name space binding data" );
@@ -127,7 +127,7 @@ public class JNDIBindingUpdater
    * Wrapper method to JNDI binding update via WS.
    *
    * @param environmentName the target environment name.
    * @param serverName      the target J2EE application server name.
    * @param bindingName     the target JNDI binding name.
    * @throws KalumetException in case of update failure.
    */
@@ -148,19 +148,19 @@ public class JNDIBindingUpdater
       LOGGER.error( "Environment {} is not found in the configuration", environmentName );
       throw new KalumetException( "Environment " + environmentName + " is not found in the configuration" );
     }
-    J2EEApplicationServer server = environment.getJ2EEApplicationServers().getJ2EEApplicationServer( serverName );
+    JEEApplicationServer server = environment.getJEEApplicationServers().getJEEApplicationServer(serverName);
     if ( server == null )
     {
-      LOGGER.error( "J2EE application server {} is not found in environment {}", serverName, environment.getName() );
+      LOGGER.error( "JEE application server {} is not found in environment {}", serverName, environment.getName() );
       throw new KalumetException(
-        "J2EE application server " + serverName + " is not found in environment " + environment.getName() );
+        "JEE application server " + serverName + " is not found in environment " + environment.getName() );
     }
     JNDIBinding jndiBinding = server.getJNDIBinding( bindingName );
     if ( jndiBinding == null )
     {
-      LOGGER.error( "JNDI binding {} is not found in J2EE application server {}", bindingName, server.getName() );
+      LOGGER.error( "JNDI binding {} is not found in JEE application server {}", bindingName, server.getName() );
       throw new KalumetException(
-        "JNDI binding " + bindingName + " is not found in J2EE application server " + server.getName() );
+        "JNDI binding " + bindingName + " is not found in JEE application server " + server.getName() );
     }
 
     // post an event and create the update log.
@@ -213,7 +213,7 @@ public class JNDIBindingUpdater
    * Check if a JNDI name space binding is up to date or not via WS.
    *
    * @param environmentName the target environment name.
    * @param serverName      the target J2EE application server name.
    * @param jndiBindingName the target JNDI binding name.
    * @return true if the JNDI name space binding is up to date, false else.
    * @throws KalumetException in case of JNDI name space binding check failure.
@@ -235,21 +235,21 @@ public class JNDIBindingUpdater
       LOGGER.error( "Environment {} is not found in the configuration", environmentName );
       throw new KalumetException( "Environment " + environmentName + " is not found in the configuration" );
     }
-    J2EEApplicationServer applicationServer =
-      environment.getJ2EEApplicationServers().getJ2EEApplicationServer( serverName );
+    JEEApplicationServer applicationServer =
+      environment.getJEEApplicationServers().getJEEApplicationServer(serverName);
     if ( applicationServer == null )
     {
-      LOGGER.error( "J2EE application server {} is not found in environment {}", serverName, environment.getName() );
+      LOGGER.error( "JEE application server {} is not found in environment {}", serverName, environment.getName() );
       throw new KalumetException(
-        "J2EE application server " + serverName + " is not found in environment " + environment.getName() );
+        "JEE application server " + serverName + " is not found in environment " + environment.getName() );
     }
     JNDIBinding jndiBinding = applicationServer.getJNDIBinding( jndiBindingName );
     if ( jndiBinding == null )
     {
-      LOGGER.error( "JNDI binding {} is not found in J2EE application server {}", jndiBindingName,
+      LOGGER.error( "JNDI binding {} is not found in JEE application server {}", jndiBindingName,
                     applicationServer.getName() );
       throw new KalumetException(
-        "JNDI binding " + jndiBindingName + " is not found in J2EE application server " + applicationServer.getName() );
+        "JNDI binding " + jndiBindingName + " is not found in JEE application server " + applicationServer.getName() );
     }
 
     // post an event
@@ -257,10 +257,10 @@ public class JNDIBindingUpdater
 
     try
     {
-      // get J2EE application server controller
-      LOGGER.debug( "Getting J2EE aplication server controller" );
-      J2EEApplicationServerController controller =
-        J2EEApplicationServerControllerFactory.getController( environment, applicationServer );
+      // get JEE application server controller
+      LOGGER.debug( "Getting JEE aplication server controller" );
+      JEEApplicationServerController controller =
+        JEEApplicationServerControllerFactory.getController(environment, applicationServer);
       // replace JNDI binding data with environment variables.
       LOGGER.debug( "Replaces variables in JNDI binding data" );
       String jndiName = VariableUtils.replace( jndiBinding.getJndiname(), environment.getVariables() );
@@ -48,12 +48,12 @@ public class JNDIBindingUpdater
    *
    * @param environment the target <code>Environment</code>.
-   * @param server      the target <code>J2EEApplicationServer</code>.
+   * @param server      the target <code>JEEApplicationServer</code>.
    * @param jndiBinding the target <code>JNDIBinding</code>.
    * @param updateLog   the <code>UpdateLog</code> to use.
@@ -127,7 +127,7 @@ public class JNDIBindingUpdater
    *
    * @param environmentName the target environment name.
-   * @param serverName      the target J2EE application server name.
+   * @param serverName      the target JEE application server name.
    * @param bindingName     the target JNDI binding name.
    * @throws KalumetException in case of update failure.
@@ -213,7 +213,7 @@ public class JNDIBindingUpdater
    *
    * @param environmentName the target environment name.
-   * @param serverName      the target J2EE application server name.
+   * @param serverName      the target JEE application server name.
    * @param jndiBindingName the target JNDI binding name.
    * @return true if the JNDI name space binding is up to date, false else.

Modified: incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SharedLibraryUpdater.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SharedLibraryUpdater.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SharedLibraryUpdater.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SharedLibraryUpdater.java Thu Aug 30 17:31:27 2012
@@ -22,10 +22,10 @@ import org.apache.kalumet.KalumetExcepti
 import org.apache.kalumet.agent.Configuration;
 import org.apache.kalumet.agent.utils.EventUtils;
 import org.apache.kalumet.controller.core.ControllerException;
-import org.apache.kalumet.controller.core.J2EEApplicationServerController;
-import org.apache.kalumet.controller.core.J2EEApplicationServerControllerFactory;
+import org.apache.kalumet.controller.core.JEEApplicationServerController;
+import org.apache.kalumet.controller.core.JEEApplicationServerControllerFactory;
 import org.apache.kalumet.model.Environment;
-import org.apache.kalumet.model.J2EEApplicationServer;
+import org.apache.kalumet.model.JEEApplicationServer;
 import org.apache.kalumet.model.Kalumet;
 import org.apache.kalumet.model.SharedLibrary;
 import org.apache.kalumet.model.update.UpdateLog;
@@ -48,12 +48,12 @@ public class SharedLibraryUpdater
    * Updates a shared library.
    *
    * @param environment   the target <code>Environment</code>.
    * @param server        the target <code>J2EEApplicationServer</code>.
    * @param sharedLibrary the target <code>SharedLibrary</code>.
    * @param updateLog     the <code>UpdateLog</code> to use.
    * @throws UpdateException in case of update failure.
    */
-  public static void update( Environment environment, J2EEApplicationServer server, SharedLibrary sharedLibrary,
+  public static void update( Environment environment, JEEApplicationServer server, SharedLibrary sharedLibrary,
                              UpdateLog updateLog )
     throws UpdateException
   {
@@ -71,17 +71,17 @@ public class SharedLibraryUpdater
                        "Shared library " + sharedLibrary.getName() + " is inactive, so not updated" );
       return;
     }
-    J2EEApplicationServerController controller = null;
+    JEEApplicationServerController controller = null;
     try
     {
-      // connect JMX controller to J2EE application server
-      LOGGER.debug( "Connecting to J2EE application server {} controller", server.getName() );
-      controller = J2EEApplicationServerControllerFactory.getController( environment, server );
+      // connect JMX controller to JEE application server
+      LOGGER.debug( "Connecting to JEE application server {} controller", server.getName() );
+      controller = JEEApplicationServerControllerFactory.getController(environment, server);
     }
     catch ( KalumetException e )
     {
-      LOGGER.error( "Can't connect to J2EE application server {} controller", server.getName(), e );
-      throw new UpdateException( "Can't connect to J2EE application server " + server.getName() + " controller", e );
+      LOGGER.error( "Can't connect to JEE application server {} controller", server.getName(), e );
+      throw new UpdateException( "Can't connect to JEE application server " + server.getName() + " controller", e );
     }
     // replaces variables in shared library class path.
     LOGGER.debug( "Replacing variables into the shared library classpath" );
@@ -126,7 +126,7 @@ public class SharedLibraryUpdater
    * Wrapper method to update shared library via WS.
    *
    * @param environmentName       the target environment name.
    * @param applicationServerName the target J2EE application server name.
    * @param sharedLibraryName     the target shared library name.
    * @throws KalumetException in case of update failure.
    */
@@ -147,21 +147,21 @@ public class SharedLibraryUpdater
       LOGGER.error( "Environment {} is not found in the configuration", environmentName );
       throw new KalumetException( "Environment " + environmentName + " is not found in the configuration" );
     }
-    J2EEApplicationServer applicationServer =
-      environment.getJ2EEApplicationServers().getJ2EEApplicationServer( applicationServerName );
+    JEEApplicationServer applicationServer =
+      environment.getJEEApplicationServers().getJEEApplicationServer(applicationServerName);
     if ( applicationServer == null )
     {
-      LOGGER.error( "J2EE application server {} is not found in environment {}", applicationServerName,
+      LOGGER.error( "JEE application server {} is not found in environment {}", applicationServerName,
                     environment.getName() );
       throw new KalumetException(
-        "J2EE application server " + applicationServerName + " is not found in environment " + environment.getName() );
+        "JEE application server " + applicationServerName + " is not found in environment " + environment.getName() );
     }
     SharedLibrary sharedLibrary = applicationServer.getSharedLibrary( sharedLibraryName );
     if ( sharedLibrary == null )
     {
-      LOGGER.error( "Shared library {} is not found in J2EE application server {}", sharedLibraryName,
+      LOGGER.error( "Shared library {} is not found in JEE application server {}", sharedLibraryName,
                     applicationServer.getName() );
-      throw new KalumetException( "Shared library " + sharedLibraryName + " is not found in J2EE application server "
+      throw new KalumetException( "Shared library " + sharedLibraryName + " is not found in JEE application server "
                                     + applicationServer.getName() );
     }
 
@@ -214,7 +214,7 @@ public class SharedLibraryUpdater
    * Check if a shared library is up to date or not via WS.
    *
    * @param environmentName   the target environment name.
    * @param serverName        the target J2EE application server name.
    * @param sharedLibraryName the target shared library name.
    * @return true if the shared library is up to date, false else.
    * @throws KalumetException in case of check failure.
@@ -236,29 +236,29 @@ public class SharedLibraryUpdater
       LOGGER.error( "Environment {} is not found in the configuration", environmentName );
       throw new KalumetException( "Environment " + environmentName + " is not found in the configuration" );
     }
-    J2EEApplicationServer applicationServer =
-      environment.getJ2EEApplicationServers().getJ2EEApplicationServer( serverName );
+    JEEApplicationServer applicationServer =
+      environment.getJEEApplicationServers().getJEEApplicationServer(serverName);
     if ( applicationServer == null )
     {
-      LOGGER.error( "J2EE application server {} is not found in environment {}", serverName, environment.getName() );
+      LOGGER.error( "JEE application server {} is not found in environment {}", serverName, environment.getName() );
       throw new KalumetException(
-        "J2EE application server " + serverName + " is not found in environment " + environment.getName() );
+        "JEE application server " + serverName + " is not found in environment " + environment.getName() );
     }
     SharedLibrary sharedLibrary = applicationServer.getSharedLibrary( sharedLibraryName );
     if ( sharedLibrary == null )
     {
-      LOGGER.error( "Shared library {} is not found in J2EE application server {}", sharedLibraryName,
+      LOGGER.error( "Shared library {} is not found in JEE application server {}", sharedLibraryName,
                     applicationServer.getName() );
-      throw new KalumetException( "Shared library " + sharedLibraryName + " is not found in J2EE application server "
+      throw new KalumetException( "Shared library " + sharedLibraryName + " is not found in JEE application server "
                                     + applicationServer.getName() );
     }
 
     try
     {
-      // get J2EE application server controller
-      LOGGER.debug( "Getting J2EE application server controller" );
-      J2EEApplicationServerController controller =
-        J2EEApplicationServerControllerFactory.getController( environment, applicationServer );
+      // get JEE application server controller
+      LOGGER.debug( "Getting JEE application server controller" );
+      JEEApplicationServerController controller =
+        JEEApplicationServerControllerFactory.getController(environment, applicationServer);
       // replaces variables in shared library class path.
       LOGGER.debug( "Replacing variables into the shared library classpath" );
       String classpath = VariableUtils.replace( sharedLibrary.getClasspath(), environment.getVariables() );
@@ -48,12 +48,12 @@ public class SharedLibraryUpdater
    *
    * @param environment   the target <code>Environment</code>.
-   * @param server        the target <code>J2EEApplicationServer</code>.
+   * @param server        the target <code>JEEApplicationServer</code>.
    * @param sharedLibrary the target <code>SharedLibrary</code>.
    * @param updateLog     the <code>UpdateLog</code> to use.
@@ -126,7 +126,7 @@ public class SharedLibraryUpdater
    *
    * @param environmentName       the target environment name.
-   * @param applicationServerName the target J2EE application server name.
+   * @param applicationServerName the target JEE application server name.
    * @param sharedLibraryName     the target shared library name.
    * @throws KalumetException in case of update failure.
@@ -214,7 +214,7 @@ public class SharedLibraryUpdater
    *
    * @param environmentName   the target environment name.
-   * @param serverName        the target J2EE application server name.
+   * @param serverName        the target JEE application server name.
    * @param sharedLibraryName the target shared library name.
    * @return true if the shared library is up to date, false else.

Modified: incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SoftwareUpdater.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SoftwareUpdater.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SqlScriptUpdater.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/agent/src/main/java/org/apache/kalumet/agent/updater/SqlScriptUpdater.java Thu Aug 30 17:31:27 2012
@@ -24,14 +24,8 @@ import org.apache.kalumet.FileManipulato
 import org.apache.kalumet.KalumetException;
 import org.apache.kalumet.agent.Configuration;
 import org.apache.kalumet.agent.utils.EventUtils;
-import org.apache.kalumet.model.Database;
-import org.apache.kalumet.model.Environment;
-import org.apache.kalumet.model.J2EEApplication;
-import org.apache.kalumet.model.J2EEApplicationServer;
-import org.apache.kalumet.model.JDBCConnectionPool;
-import org.apache.kalumet.model.Kalumet;
-import org.apache.kalumet.model.Mapping;
-import org.apache.kalumet.model.SqlScript;
+import org.apache.kalumet.model.*;
+import org.apache.kalumet.model.JEEApplication;
 import org.apache.kalumet.model.update.UpdateLog;
 import org.apache.kalumet.model.update.UpdateMessage;
 import org.apache.kalumet.utils.NotifierUtils;
@@ -55,14 +49,14 @@ public class SqlScriptUpdater
    * Executes SQL script.
    *
    * @param environment the target <code>Environment</code>.
    * @param server      the target <code>J2EEApplicationServer</code>.
    * @param application the target <code>J2EEApplication</code>.
    * @param database    the target <code>Database</code>.
    * @param sqlScript   the target <code>SqlScript</code>.
    * @param updateLog   the <code>UpdateLog</code> to use.
    * @throws UpdateException in case of update failure.
    */
-  public static void execute( Environment environment, J2EEApplicationServer server, J2EEApplication application,
+  public static void execute( Environment environment, JEEApplicationServer server, JEEApplication application,
                               Database database, SqlScript sqlScript, UpdateLog updateLog )
     throws UpdateException
   {
@@ -85,8 +79,8 @@ public class SqlScriptUpdater
     if ( !FileManipulator.protocolExists( sqlScriptUri ) )
     {
       // the SQL script URI is relative , construct the SQL Script URI using
-      // the J2EE Application URI
-      LOGGER.debug( "SQL Script URI is relative to J2EE application URI" );
+      // the JEE Application URI
+      LOGGER.debug( "SQL Script URI is relative to JEE application URI" );
       sqlScriptUri =
         FileManipulator.format( VariableUtils.replace( application.getUri(), environment.getVariables() ) ) + "!/"
           + sqlScriptUri;
@@ -95,12 +89,12 @@ public class SqlScriptUpdater
     String applicationCacheDir = null;
     try
     {
-      applicationCacheDir = FileManipulator.createJ2EEApplicationCacheDir( environment, application );
+      applicationCacheDir = FileManipulator.createJEEApplicationCacheDir( environment, application );
     }
     catch ( FileManipulatorException fileManipulatorException )
     {
-      LOGGER.error( "Can't initialize J2EE application cache directory", fileManipulatorException );
-      throw new UpdateException( "Can't initialize J2EE application cache directory", fileManipulatorException );
+      LOGGER.error( "Can't initialize JEE application cache directory", fileManipulatorException );
+      throw new UpdateException( "Can't initialize JEE application cache directory", fileManipulatorException );
     }
 
     // get file manipulator instance
@@ -185,10 +179,10 @@ public class SqlScriptUpdater
                 JDBCConnectionPool connectionPool = server.getJDBCConnectionPool( connectionPoolName );
                 if ( connectionPool == null )
                 {
-                  LOGGER.error( "JDBC connection pool {} is not found in J2EE application server {}",
+                  LOGGER.error( "JDBC connection pool {} is not found in JEE application server {}",
                                 database.getConnectionPool(), server.getName() );
                   throw new UpdateException(
-                    "JDBC connection pool " + database.getConnectionPool() + " is not found in J2EE application server "
+                    "JDBC connection pool " + database.getConnectionPool() + " is not found in JEE application server "
                       + server.getName() );
                 }
                 user = VariableUtils.replace( connectionPool.getUser(), environment.getVariables() );
@@ -280,10 +274,10 @@ public class SqlScriptUpdater
               JDBCConnectionPool connectionPool = server.getJDBCConnectionPool( connectionPoolName );
               if ( connectionPool == null )
               {
-                LOGGER.error( "JDBC connection pool {} is not found in J2EE application server {}",
+                LOGGER.error( "JDBC connection pool {} is not found in JEE application server {}",
                               database.getConnectionPool(), server.getName() );
                 throw new UpdateException(
-                  "JDBC connection pool " + database.getConnectionPool() + " is not found in J2EE application server "
+                  "JDBC connection pool " + database.getConnectionPool() + " is not found in JEE application server "
                     + server.getName() );
               }
               user = VariableUtils.replace( connectionPool.getUser(), environment.getVariables() );
@@ -341,8 +335,8 @@ public class SqlScriptUpdater
    * Wrapper method to execute a SQL script via WS.
    *
    * @param environmentName the target environment name.
    * @param serverName      the target J2EE application server name.
    * @param applicationName the target J2EE application name.
    * @param databaseName    the target database name.
    * @param sqlScriptName   the target SQL script name.
    * @throws KalumetException in case of execution failure.
@@ -365,28 +359,28 @@ public class SqlScriptUpdater
       LOGGER.error( "Environment {} is not found in the configuration", environmentName );
       throw new KalumetException( "Environment " + environmentName + " is not found in the configuration" );
     }
-    J2EEApplicationServer applicationServer =
-      environment.getJ2EEApplicationServers().getJ2EEApplicationServer( serverName );
+    JEEApplicationServer applicationServer =
+      environment.getJEEApplicationServers().getJEEApplicationServer( serverName );
     if ( applicationServer == null )
     {
-      LOGGER.error( "J2EE application server {} is not found in environment {}", serverName, environment.getName() );
+      LOGGER.error( "JEE application server {} is not found in environment {}", serverName, environment.getName() );
       throw new KalumetException(
-        "J2EE application server " + serverName + " is not found in environment " + environment.getName() );
+        "JEE application server " + serverName + " is not found in environment " + environment.getName() );
     }
-    J2EEApplication application = applicationServer.getJ2EEApplication( applicationName );
+    JEEApplication application = applicationServer.getJEEApplication( applicationName );
     if ( application == null )
     {
-      LOGGER.error( "J2EE application {} is not found in J2EE application server {}", applicationName,
+      LOGGER.error( "JEE application {} is not found in JEE application server {}", applicationName,
                     applicationServer.getName() );
-      throw new KalumetException( "J2EE application " + applicationName + " is not found in J2EE application server "
+      throw new KalumetException( "JEE application " + applicationName + " is not found in JEE application server "
                                     + applicationServer.getName() );
     }
     Database database = application.getDatabase( databaseName );
     if ( database == null )
     {
-      LOGGER.error( "Database {} is not found in J2EE application {}", databaseName, application.getName() );
+      LOGGER.error( "Database {} is not found in JEE application {}", databaseName, application.getName() );
       throw new KalumetException(
-        "Database " + databaseName + " is not found in J2EE application " + application.getName() );
+        "Database " + databaseName + " is not found in JEE application " + application.getName() );
     }
     SqlScript sqlScript = database.getSqlScript( sqlScriptName );
     if ( sqlScript == null )
@@ -55,14 +49,14 @@ public class SqlScriptUpdater
    *
    * @param environment the target <code>Environment</code>.
-   * @param server      the target <code>J2EEApplicationServer</code>.
-   * @param application the target <code>J2EEApplication</code>.
+   * @param server      the target <code>JEEApplicationServer</code>.
+   * @param application the target <code>JEEApplication</code>.
    * @param database    the target <code>Database</code>.
    * @param sqlScript   the target <code>SqlScript</code>.
@@ -341,8 +335,8 @@ public class SqlScriptUpdater
    *
    * @param environmentName the target environment name.
-   * @param serverName      the target J2EE application server name.
-   * @param applicationName the target J2EE application name.
+   * @param serverName      the target JEE application server name.
+   * @param applicationName the target JEE application name.
    * @param databaseName    the target database name.
    * @param sqlScriptName   the target SQL script name.

Modified: incubator/kalumet/trunk/kalumet-modules/agent/src/main/resources/apache-kalumet.wsdd
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/agent/src/main/resources/apache-kalumet.wsdd?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================
--- incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/FileManipulator.java (original)
+++ incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/FileManipulator.java Thu Aug 30 17:31:27 2012
@@ -30,7 +30,7 @@ import org.apache.commons.vfs.Selectors;
 import org.apache.commons.vfs.VFS;
 import org.apache.commons.vfs.impl.StandardFileSystemManager;
 import org.apache.kalumet.model.Environment;
-import org.apache.kalumet.model.J2EEApplication;
+import org.apache.kalumet.model.JEEApplication;
 import org.apache.kalumet.model.Software;
 import org.apache.oro.text.regex.MalformedPatternException;
 import org.apache.oro.text.regex.Pattern;
@@ -600,18 +600,18 @@ public class FileManipulator
   }
 
   /**
    * Creates an environment j2EEApplication cache directory.
    *
    * @param environment     the <code>Environment</code>.
    * @param j2EEApplication the <code>J2EEApplication</code>.
    * @return the environment j2EEApplication cache directory path.
    * @throws FileManipulatorException in case of creation failure.
    */
-  public static String createJ2EEApplicationCacheDir( Environment environment, J2EEApplication j2EEApplication )
+  public static String createJEEApplicationCacheDir( Environment environment, JEEApplication jeeApplication )
     throws FileManipulatorException
   {
     String directory = FileManipulator.createEnvironmentCacheDir( environment );
-    directory = directory + "/applications/" + j2EEApplication.getName();
+    directory = directory + "/applications/" + jeeApplication.getName();
     FileManipulator fileManipulator = new FileManipulator();
     fileManipulator.createDirectory( directory );
     fileManipulator.close();
@@ -600,18 +600,18 @@ public class FileManipulator
 
   /**
-   * Creates an environment j2EEApplication cache directory.
+   * Creates an environment jeeApplication cache directory.
    *
    * @param environment     the <code>Environment</code>.
@@ -600,18 +600,18 @@ public class FileManipulator
    *
    * @param environment     the <code>Environment</code>.
-   * @param j2EEApplication the <code>J2EEApplication</code>.
-   * @return the environment j2EEApplication cache directory path.
+   * @param jeeApplication the <code>JEEApplication</code>.
+   * @return the environment jeeApplication cache directory path.
    * @throws FileManipulatorException in case of creation failure.
    */

Modified: incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/Agent.java
URL: http://svn.apache.org/viewvc/incubator/kalumet/trunk/kalumet-modules/common/src/main/java/org/apache/kalumet/model/Agent.java?rev=1379028&r1=1379027&r2=1379028&view=diff
==============================================================================